<?php
namespace inshok\project\controllers;

use \inshok\project\controllers\interfaces\InterfaceProcess;
use \inshok\project\helpers\Html;

use \inshok\project\database\PdoScheduling;
use \inshok\project\helpers\WhatsappLink;

use DateTime;



class MainController implements InterfaceProcess {

    
    use Html;

    
    private $dayweek_full = [
        'Sun' => 'Domingo',
        'Mon' => 'Segunda-Feira',
        'Tue' => 'Terca-Feira',
        'Wed' => 'Quarta-Feira',
        'Thu' => 'Quinta-Feira',
        'Fri' => 'Sexta-Feira',
        'Sat' => 'Sábado'
    ];

    private $month_full = [
        'Jan' => 'janeiro',
        'Feb' => 'fevereiro',
        'Mar' => 'marco',
        'Apr' => 'abril',
        'May' => 'maio',
        'Jun' => 'junho',
        'Jul' => 'julho',
        'Aug' => 'agosto',
        'Nov' => 'novembro',
        'Sep' => 'setembro',
        'Oct' => 'outubro',
        'Dec' => 'dezembro'
    ];

    private $messages = [
        'A fila está normal, a previsão é você seja atendido no horário marcado.',
        'Você é o primeiro da fila, não se atrase.',
        'Os atendimentos ainda não começaram.',
        'A fila está atrasada, acompanhe o horário previsto para o seu atendimento.',
        'Paciente já foi atendido.',
        'O dia do seu atendimento ainda não chegou.',
    ];

    public function process(): void
    {



        $data = $this->loadData();


        if( empty($data) || !isset($data) ) {

            $path = 'notfound/notfound.php';
            echo $this->render( $path , []);

        } else {

            $message_return = intval(  $data['mensagem_de_retorno'] );
            $position = $data['minha_posicao_na_fila'] . 'º';
            if($message_return == 5 || $message_return == 4) {
                $position = '-';
            }
            
            
            $message = $this->messages[ $message_return ];



            $args = [
                'pathJS' => 'main.js',
                //'time' => $this->formatTime( $data['tempo_estimado_para_atendimento'] ),
                'estimedTime' => $this->formatEstimatedTime( $data['horario_previsto_para_meu_atendimento'] ),
                'consultation' =>  $this->formatConsultationDate( $data['scheduling_dateconsultation'] ),
                'message' => $message,
                'position' => $position,
                'patient' => $data['patient_name'],
                'doctor' => $data['doctor_name'],
                'clinic' => $data['clinic_name'],
                'clinic_message' => $data['messages_text'],
                'landline' => $data['cliniccontact_landline'],
                'whatsapp' => WhatsappLink::convert( $data['cliniccontact_cel1'] ),
                'googlemaps' => $data['clinicadress_googlemaps'],
                'waze' => $data['clinicadress_waze'],
            ];
    
            $path = 'main/main.php';
            echo $this->render($path , $args);
    
        }

    }


    private function loadData() {
        
        $key = filter_input(INPUT_GET, 'key', FILTER_SANITIZE_STRING);
        $pdo = new PdoScheduling();

        return $pdo->list( $key );
    }


    private function formatEstimatedTime( $time ) {
        $date_time = new DateTime( $time );
        return $date_time->format('H:i');
    }

    private function formatTime( $time ) {
        $date_time = new DateTime( $time );
        return $date_time->format('H') . ' hora, ' . $date_time->format('i') . ' minutos e ' . $date_time->format('s') . ' segundos';
    }

    private function formatConsultationDate( $consultation_date ) {

        $date_time = new DateTime( $consultation_date );
        return 'Dia ' . $date_time->format('d') . ' de ' . $this->month_full[$date_time->format('M') ] . ' de ' . $date_time->format('Y') . ', às ' . $date_time->format('H:i') . '.';

    }


 
}