<?php
namespace inshok\admin\controllers\admin;

use \inshok\admin\controllers\interfaces\InterfaceProcess;
use \inshok\admin\helpers\Html;
use \inshok\admin\helpers\Message;
use \inshok\admin\database\PdoScheduling;
use \inshok\admin\database\PdoDoctor;
use \inshok\admin\database\PdoClinic;


class InsertAppoimentController implements InterfaceProcess {

    
    use Html;


    public function process(): void
    {

        $action = filter_input(INPUT_GET , 'action' , FILTER_SANITIZE_STRING);
        $id = filter_input(INPUT_GET , 'id' , FILTER_SANITIZE_STRING);


        $login = AdminController::login();
        $login_id = $login['id'];

        $pdo_scheduling = new PdoScheduling();
        
        if( empty($action) ) $action = 'insert';
        $scheduling_id = 0;
        $page_title = 'Inserir Consulta';

        if( $action == 'update' ) {

            $pdo_scheduling_list = $pdo_scheduling->fulllist( $id , '0' , '0000-00-00' );
            $action = 'update';
            $scheduling_id = $id;
            $page_title = 'Alterar Consulta';

        }


        if( $_POST ) {

            $scheduling_dateconsultation_time = filter_input(INPUT_POST , 'scheduling_dateconsultation_time' , FILTER_SANITIZE_STRING);
            $scheduling_dateconsultation_date = filter_input(INPUT_POST , 'scheduling_dateconsultation_date' , FILTER_SANITIZE_STRING);
            $scheduling_dateconsultation = $scheduling_dateconsultation_date . ' ' . $scheduling_dateconsultation_time;

            $v_scheduling_key = base64_encode(openssl_random_pseudo_bytes(32));
            $v_scheduling_key = str_replace('+','',$v_scheduling_key);

            $post_vars = [
                'scheduling_id' => $scheduling_id,
                'user_id' => $login_id,
                'patient_name' => filter_input(INPUT_POST , 'patient_name' , FILTER_SANITIZE_STRING),
                'patient_whatsapp' => filter_input(INPUT_POST , 'patient_whatsapp' , FILTER_SANITIZE_STRING),
                'patient_email' => filter_input(INPUT_POST , 'patient_email' , FILTER_SANITIZE_STRING),
                'scheduling_description' => filter_input(INPUT_POST , 'scheduling_description' , FILTER_SANITIZE_STRING),
                'scheduling_dateconsultation' => $scheduling_dateconsultation,
                'scheduling_key' => $v_scheduling_key,
                'doctor_id' => filter_input(INPUT_POST , 'doctor_id' , FILTER_SANITIZE_STRING),
                'clinic_id' => filter_input(INPUT_POST , 'clinic_id' , FILTER_SANITIZE_STRING)
            ];

            
            $pdo_scheduling_save = $pdo_scheduling->save( $post_vars );
            
            if( $pdo_scheduling_save ) {

                $message_return = intval( $pdo_scheduling_save['message_return'] );
                if( $message_return == 1) {

                    Message::set( 'Consulta cadastrada com sucesso' );

                } elseif( $message_return == 2 ) {
                
                    Message::set( 'Consulta alterada com sucesso' );
                    Header ('Location: /lista-consultas');

                } elseif( $message_return == 3 ) {
                
                    Message::set('E-mail já cadastrado');
                
                }

                // header( 'Location: ./lista-usuarios' ); 

            }


        }

        $text_button = 'Inserir Consulta';
        if( isset( $pdo_scheduling_list )) {
            $text_button = 'Alterar Consulta';
        }

        $pdo_doctor = new PdoDoctor();
        $doctor_id = 0;
        $pdo_doctor_list = $pdo_doctor->fulllist( $login_id , $doctor_id );


        $pdo_clinic = new PdoClinic();
        $pdo_clinic_list = $pdo_clinic->fulllist( $login_id );
        
    
        $args = [
            'pathJS' => 'insert-scheduling.js',
            'access' => $login['access'],
            'message_return_text' => Message::get(),
            'text_button' => $text_button,
            'action' => $action,
            'page_title' => $page_title
        ];

        if( isset( $message_return ) ) {
            $args['message_return'] = $message_return;
        }


        if( isset( $pdo_scheduling_list )) {
            $args['scheduling_list'] = $pdo_scheduling_list;
        }

        if( isset($pdo_doctor_list) ) {
            $args['doctor_list'] = $pdo_doctor_list;
        }
        
        if( isset($pdo_clinic_list) ) {
            $args['clinic_list'] = $pdo_clinic_list;
        }

        

        $path = 'admin/insert-scheduling.php';
        echo $this->render($path , $args);


        Message::destroy();
    

    }

}
