<?php
namespace inshok\admin\controllers\admin;

use \inshok\admin\controllers\interfaces\InterfaceProcess;
use \inshok\admin\helpers\Html;
use \inshok\admin\helpers\Message;
use \inshok\admin\database\PdoUser;
use inshok\admin\helpers\SendMail;

class InsertUserController implements InterfaceProcess {

    
    use Html;
    use SendMail;


    public function process(): void
    {


        $action = filter_input(INPUT_GET , 'action' , FILTER_SANITIZE_STRING);
        $id = filter_input(INPUT_GET , 'id' , FILTER_SANITIZE_STRING);



        $login = AdminController::login();
        $login_id = $login['id'];

        $pdo_user = new PdoUser();
        
        if( empty($action) ) $action = 'insert';
        $user_id = 0;
        $page_title = 'Inserir Usuário';

        if( $action == 'update' ) {

            $pdo_user_list = $pdo_user->list( $id );
            $user_id = $id;
            $page_title = 'Alterar Usuário';
        }



        if( $_POST ) {


            $pass_pure = filter_input(INPUT_POST , 'userlogin_pass' , FILTER_SANITIZE_STRING);


            $post_vars = [
                'user_id' => $user_id,
                'user_access' => filter_input(INPUT_POST , 'user_access' , FILTER_SANITIZE_STRING),
                'user_name' => filter_input(INPUT_POST , 'user_name' , FILTER_SANITIZE_STRING),
                'user_cpf' => filter_input(INPUT_POST , 'user_cpf' , FILTER_SANITIZE_STRING),
                'usercontact_email' => filter_input(INPUT_POST , 'usercontact_email' , FILTER_SANITIZE_STRING),
                'usercontact_cel1' => filter_input(INPUT_POST , 'usercontact_cel1' , FILTER_SANITIZE_STRING), // Whatsapp
                'userlogin_pass' => $this->encryptPass( $pass_pure ),
            ];
    

            $pdo_user_save = $pdo_user->save( $post_vars );
            if( $pdo_user_save ) {

                $message_return = intval( $pdo_user_save['message_return'] );
                if( $message_return == 1) {

                    Message::set( 'Usuário cadastrado com sucesso' );


                    $this->sendPostMail( $post_vars , $pass_pure );


                } elseif( $message_return == 2 ) {
                
                    Message::set( 'Usuário alterado com sucesso' );
                    Header ('Location: /lista-usuarios');

                } elseif( $message_return == 3 ) {
                
                    Message::set('E-mail já cadastrado');
                
                }

                // header( 'Location: ./lista-usuarios' ); 

            }


        }

        $text_button = 'Inserir Usuário Sua Espera';
        if( isset( $pdo_user_list )) {
            $text_button = 'Alterar Usuário Sua Espera';
        }


        // Página da lista de usuários
        // 
    
        $args = [
            'pathJS' => 'insert-user.js',
            'access' => $login['access'],
            'message_return_text' => Message::get(),
            'text_button' => $text_button,
            'action' => $action,
            'page_title' => $page_title
        ];

        if( isset( $message_return ) ) {
            $args['message_return'] = $message_return;
        }

        if( isset( $pdo_user_list )) {
            $args['pdo_user_list'] = $pdo_user_list;
        }

        

        $path = 'admin/insert-user.php';
        echo $this->render($path , $args);


        Message::destroy();
    

    }
    

    private function encryptPass( $pass ) {

        $options = [
            'cost' => 12,
        ];

        $pass_encrypted = password_hash($pass , PASSWORD_BCRYPT, $options);

        return $pass_encrypted;
    }

    private function sendPostMail( $post_vars , $pass_pure ) {

        $args = [
            'user' => $post_vars['user_name'],
            'email' => $post_vars['usercontact_email'],
            'template' => 'register-admin.php',
            'subject' => 'Você foi registrado no sistema Sua Espera',
            'message' => '',
            'pass' => $pass_pure
        ];

        

        $this->send( $args );

    }

}