<?php 
namespace inshok\admin\database;

use inshok\admin\database\ConnectionCreator;


use PDO;

class PdoClinic 
{

    public function __construct()
    {
        
        $this->connection = ConnectionCreator::createConnection();

    }

    public function list( $clinic_id , $user_id ) 
    {


        $sqlInstruction = 'CALL P_ListClinic( :user_id , :clinic_id )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':user_id', $user_id , PDO::PARAM_STR);
        $statement->bindValue(':clinic_id', $clinic_id , PDO::PARAM_STR);
        $statement->execute();
        
        $data = $statement->fetch(PDO::FETCH_ASSOC);

        return $data;
    }


    public function fulllist( $user_id ) 
    {


        $sqlInstruction = 'CALL P_ListClinic( :user_id , :clinic_id )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':user_id', $user_id , PDO::PARAM_STR);
        $statement->bindValue(':clinic_id', 0 , PDO::PARAM_STR);
        $statement->execute();

        $data_array = [];
        while($data = $statement->fetch(PDO::FETCH_ASSOC)) {
            $data_array[] = [
                'clinic_id' => $data["clinic_id"],
                'clinic_name' => $data["clinic_name"],
                'clinic_description' => $data["clinic_description"],
                'clinic_active' => $data["clinic_active"],
                'cliniccontact_email' => $data["cliniccontact_email"],
                'cliniccontact_cel1' =>  $data["cliniccontact_cel1"],
                'cliniccontact_landline' => $data["cliniccontact_landline"]
            ];
        }

        return $data_array;
    }


    

    public function save( $post_vars )
    {

       
        $sqlInstruction = 'CALL P_UpdateClinic( :user_id, :clinic_id, :clinic_name, :clinic_description )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':user_id', $post_vars['user_id'] , PDO::PARAM_INT);
        $statement->bindValue(':clinic_id', $post_vars['clinic_id'] , PDO::PARAM_INT);
        $statement->bindValue(':clinic_name', $post_vars['clinic_name'] , PDO::PARAM_STR);
        $statement->bindValue(':clinic_description', $post_vars['clinic_description'] , PDO::PARAM_STR);
        $statement->execute();
        
        $data = $statement->fetch(PDO::FETCH_ASSOC);

        return $data;
        
    }

    public function saveLinks( $post_vars )
    {

        $sqlInstruction = 'CALL P_UpdateClinicLinks( :user_id, :clinic_id, :clinicadress_waze, :clinicadress_googlemaps )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':user_id', $post_vars['user_id'] , PDO::PARAM_INT);
        $statement->bindValue(':clinic_id', $post_vars['clinic_id'] , PDO::PARAM_INT);
        $statement->bindValue(':clinicadress_waze', $post_vars['clinicadress_waze'] , PDO::PARAM_STR);
        $statement->bindValue(':clinicadress_googlemaps', $post_vars['clinicadress_googlemaps'] , PDO::PARAM_STR);
        $statement->execute();
        
        $data = $statement->fetch(PDO::FETCH_ASSOC);

        return $data;
        
    }

    public function saveAddress( $post_vars )
    {


        $sqlInstruction = 'CALL P_UpdateClinicAdress( :user_id, :clinic_id, :clinicadress_1, :clinicadress_2, :clinicadress_number, :clinicadress_complement, :clinicadress_district, :clinicadress_zipcode, :clinicadress_city, :clinicadress_state, :clinicadress_country )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':user_id', $post_vars['user_id'] , PDO::PARAM_INT);
        $statement->bindValue(':clinic_id', $post_vars['clinic_id'] , PDO::PARAM_INT);
        $statement->bindValue(':clinicadress_1', $post_vars['clinicadress_1'] , PDO::PARAM_STR);
        $statement->bindValue(':clinicadress_2', $post_vars['clinicadress_2'] , PDO::PARAM_STR);
        $statement->bindValue(':clinicadress_number', $post_vars['clinicadress_number'] , PDO::PARAM_STR);
        $statement->bindValue(':clinicadress_complement', $post_vars['clinicadress_complement'] , PDO::PARAM_STR);
        $statement->bindValue(':clinicadress_district', $post_vars['clinicadress_district'] , PDO::PARAM_STR);
        $statement->bindValue(':clinicadress_zipcode', $post_vars['clinicadress_zipcode'] , PDO::PARAM_INT);
        $statement->bindValue(':clinicadress_city', $post_vars['clinicadress_city'] , PDO::PARAM_STR);
        $statement->bindValue(':clinicadress_state', $post_vars['clinicadress_state'] , PDO::PARAM_STR);
        $statement->bindValue(':clinicadress_country', $post_vars['clinicadress_country'] , PDO::PARAM_STR);
        $statement->execute();
        
        $data = $statement->fetch(PDO::FETCH_ASSOC);

        return $data;
        
    }

    
    public function saveContacts( $post_vars )
    {


        $sqlInstruction = 'CALL P_UpdateClinicContact( :user_id, :clinic_id, :cliniccontact_email, :cliniccontact_landline, :cliniccontact_cel1, :cliniccontact_cel2, :cliniccontact_cel3 )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':user_id', $post_vars['user_id'] , PDO::PARAM_INT);
        $statement->bindValue(':clinic_id', $post_vars['clinic_id'] , PDO::PARAM_INT);
        $statement->bindValue(':cliniccontact_email', $post_vars['cliniccontact_email'] , PDO::PARAM_STR);
        $statement->bindValue(':cliniccontact_landline', $post_vars['cliniccontact_landline'] , PDO::PARAM_STR);
        $statement->bindValue(':cliniccontact_cel1', $post_vars['cliniccontact_cel1'] , PDO::PARAM_STR);
        $statement->bindValue(':cliniccontact_cel2', $post_vars['cliniccontact_cel2'] , PDO::PARAM_STR);
        $statement->bindValue(':cliniccontact_cel3', $post_vars['cliniccontact_cel3'] , PDO::PARAM_STR);
        $statement->execute();
        
        $data = $statement->fetch(PDO::FETCH_ASSOC);

        return $data;
        
    }


    



    public function delete( $id , $user_id )
    {

        $sqlInstruction = 'CALL P_DeleteClinic( :user_id , :clinic_id )';
        $statement = $this->connection->prepare($sqlInstruction);
        $statement->bindValue(':clinic_id', $id , PDO::PARAM_INT);
        $statement->bindValue(':user_id', $user_id , PDO::PARAM_INT);
        
        return $statement->execute();;
    }

}


